@@ -8,6 +8,7 @@ except:
 from re import findall
 from time import strftime
 from urllib import parse
+from datetime import datetime
 
 import json
 
@@ -47,7 +48,7 @@ class Api(xuexitong.Xuexitong):
         msg = []
 
         for result in self.reserveList:
-            resmsg = "%s-%s 座位号: %s"%( result.get("firstLevelName") ,result.get("secondLevelName") ,result.get("seatNum"))
+            resmsg = "%s %s %s-%s 座位号: %s"%(parse.unquote(self.requests.cookies.get("oa_name","")),datetime.fromtimestamp(int(result.get('startTime')/1000)), result.get("firstLevelName") ,result.get("secondLevelName") ,result.get("seatNum"))
             msg.append(resmsg)
         
         print(msg)
